DownloadProgressEntity class

下载进度实体

Constructors

DownloadProgressEntity.fromJson(dynamic data)

Properties

currentSize ↔ int
当前下载大小
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
msgId ↔ String
消息ID
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalSize ↔ int
总大小
getter/setter pair
type ↔ DownloadTypeEnum
下载类型
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited