ErrorEntity class

错误实体

Constructors

ErrorEntity.fromJson(dynamic data)

Properties

code ↔ int
错误码
getter/setter pair
error ↔ String?
错误描述
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited