GroupApplicationResultEntity class

群申请列表结果实体

Constructors

GroupApplicationResultEntity.fromJson(dynamic data)

Properties

groupApplicationList ↔ List<GroupApplicationEntity>
加群的申请列表
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unreadCount ↔ int
未读申请数量
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited