FaceMessageNode class

表情消息节点

Inheritance

Constructors

FaceMessageNode({required int index, required String data})
FaceMessageNode.fromJson(Map<String, dynamic> json)

Properties

data ↔ String
数据
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
index ↔ int
索引
getter/setter pair
nodeType ↔ MessageElemTypeEnum
新消息节点类型
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited