ImageMessageNode class

图片消息节点

Inheritance

Constructors

ImageMessageNode({required String? path})
ImageMessageNode.fromJson(Map<String, dynamic> json)

Properties

hashCode → int
The hash code for this object.
no setterinherited
imageData → Map<ImageTypeEnum, ImageEntity>?
获得图片列表
no setter
nodeType ↔ MessageElemTypeEnum
新消息节点类型
getter/setter pairinherited
path ↔ String?
图片路径
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited