LocationMessageNode class

位置节点

Inheritance

Constructors

LocationMessageNode({required String desc, required double longitude, required double latitude})
LocationMessageNode.fromJson(Map<String, dynamic> json)

Properties

desc ↔ String
位置描述
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
latitude ↔ double
纬度
getter/setter pair
longitude ↔ double
经度
getter/setter pair
nodeType ↔ MessageElemTypeEnum
新消息节点类型
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited