SoundMessageNode class

语音消息节点

Inheritance

Constructors

SoundMessageNode({required String? path, required int duration})
SoundMessageNode.fromJson(Map<String, dynamic> json)

Properties

dataSize → int?
获得数据大小
no setter
duration ↔ int
时长
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nodeType ↔ MessageElemTypeEnum
新消息节点类型
getter/setter pairinherited
path ↔ String?
路径
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uuid → String?
获得语音ID
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited