VideoMessageNode class

适配消息节点

Inheritance

Constructors

VideoMessageNode({required String? videoPath, required int duration, required String? snapshotPath})
VideoMessageNode.fromJson(Map<String, dynamic> json)

Properties

duration ↔ int
时长
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nodeType ↔ MessageElemTypeEnum
新消息节点类型
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapshotHeight → int?
获得缩略图高度
no setter
snapshotPath ↔ String?
缩略图路径
getter/setter pair
snapshotSize → int?
获得缩略图大小
no setter
snapshotUuid → String?
获得缩略图UUID
no setter
snapshotWidth → int?
获得缩略图宽度
no setter
videoPath ↔ String?
视频路径
getter/setter pair
videoSize → int?
获得视频大小
no setter
videoUuid → String?
获得视频UUID
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited